projectal.entities.activity API documentation

# projectal.entities.activity

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import *
     3
     4
     5class Activity(
     6    Entity,
     7    BookingLinker,
     8    ContactLinker,
     9    LocationLinker,
    10    NoteLinker,
    11    FileLinker,
    12    RebateLinker,
    13    ResourceLinker,
    14    StaffLinker,
    15    StageLinker,
    16    TagLinker,
    17):
    18    """
    19    Implementation of the [Activity](https://projectal.com/docs/latest/#tag/Activity) API.
    20    """
    21
    22    _path = "activity"
    23    _name = "activity"
    24    _links = [
    25        BookingLinker,
    26        ContactLinker,
    27        LocationLinker,
    28        NoteLinker,
    29        FileLinker,
    30        RebateLinker,
    31        ResourceLinker,
    32        StaffLinker,
    33        StageLinker,
    34        TagLinker,
    35    ]

class Activity(projectal.entity.Entity, projectal.linkers.BookingLinker, projectal.linkers.ContactLinker, projectal.linkers.LocationLinker, projectal.linkers.NoteLinker, projectal.linkers.FileLinker, projectal.linkers.RebateLinker, projectal.linkers.ResourceLinker, projectal.linkers.StaffLinker, projectal.linkers.StageLinker, projectal.linkers.TagLinker): View Source

     6class Activity(
     7    Entity,
     8    BookingLinker,
     9    ContactLinker,
    10    LocationLinker,
    11    NoteLinker,
    12    FileLinker,
    13    RebateLinker,
    14    ResourceLinker,
    15    StaffLinker,
    16    StageLinker,
    17    TagLinker,
    18):
    19    """
    20    Implementation of the [Activity](https://projectal.com/docs/latest/#tag/Activity) API.
    21    """
    22
    23    _path = "activity"
    24    _name = "activity"
    25    _links = [
    26        BookingLinker,
    27        ContactLinker,
    28        LocationLinker,
    29        NoteLinker,
    30        FileLinker,
    31        RebateLinker,
    32        ResourceLinker,
    33        StaffLinker,
    34        StageLinker,
    35        TagLinker,
    36    ]

Implementation of the Activity API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.BookingLinker
  link_booking
  unlink_booking
projectal.linkers.ContactLinker
  link_contact
  unlink_contact
projectal.linkers.LocationLinker
  link_location
  unlink_location
projectal.linkers.FileLinker
  link_file
  unlink_file
projectal.linkers.RebateLinker
  link_rebate
  unlink_rebate
projectal.linkers.ResourceLinker
  link_resource
  relink_resource
  unlink_resource
projectal.linkers.StaffLinker
  link_staff
  relink_staff
  unlink_staff
projectal.linkers.StageLinker
  link_stage
  unlink_stage
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy